@@ -20,7 +20,7 @@ from . import dialogs
 
 # List extra packages that aren't necessarily marked in their control files, but
 # we know better...
-CRITICAL_PACKAGES = ["mint-common", "mint-meta-core", "mintdesktop", "python3"]
+CRITICAL_PACKAGES = ["mint-common", "mint-meta-core", "mintdesktop", "python3", "perl"]
 
 def capitalize(string):
     if len(string) > 1:
@@ -117,11 +117,11 @@ def process_full_apt_cache(cache):
             else:
                 section = section_string
 
-        try:
-            sections[section].append(pkg_hash)
-        except Exception:
-            sections[section] = []
-            sections[section].append(pkg_hash)
+            try:
+                sections[section].append(pkg_hash)
+            except Exception:
+                sections[section] = []
+                sections[section].append(pkg_hash)
 
         cache[pkg_hash] = AptPkgInfo(pkg_hash, pkg)
 
@@ -162,7 +162,7 @@ def pkginfo_is_installed(pkginfo):
 
     with _apt_cache_lock:
         try:
-            return apt_cache[pkginfo.name].installed != None
+            return apt_cache[pkginfo.name].installed is not None
         except:
             return False
 
@@ -244,7 +244,10 @@ class MetaTransaction(packagekit.Task):
             self.task.info_ready_status = self.task.STATUS_FORBIDDEN
 
         if self.task.info_ready_status == self.task.STATUS_NONE:
-            self.task.info_ready_status = self.task.STATUS_UNKNOWN
+            if real_code == packagekit.ErrorEnum.DEP_RESOLUTION_FAILED:
+                self.task.info_ready_status = self.task.STATUS_BROKEN
+            else:
+                self.task.info_ready_status = self.task.STATUS_UNKNOWN
 
         self.task.handle_error(error, info_stage = self.get_simulate())
 
@@ -391,7 +394,7 @@ class MetaTransaction(packagekit.Task):
         if self.task.cancellable.is_cancelled():
             return
 
-        if self.task.client_progress_cb != None:
+        if self.task.client_progress_cb is not None:
             self.task.has_window = True
 
         if self.task.has_window:
